import os


class TestCli(object):

    def run_cmd(self, cmd):
        result = os.popen(cmd)
        return result

    def equal(self, cmd, expect):
        run = self.run_cmd(cmd)
        result = run.read()
        # self.assertEqual(result, expect, "Unexpected Result")
        assert result.find(expect) >= 0



# encoding: utf-8
"""
如何自定义插件
1. 定义一个 spec 对象，参考以下代码
2. export 一个函数，名字叫做 register_service，它负责向 cli 注册 spec

注册完成后，用户可以通过 tccli {服务名} {接口名} --{参数1}={参数值} ... 的方式调用

如下所示:
    定义了一个服务名叫 test, 包含一个接口 add, add 接口接受 2 个参数 number1, number2
    则用户可以以如下方式调用 tccli
    tccli test add --number1=3 --number2=5
"""
from tccli.plugins.test.add import add_command

service_name = "test"
service_version = "2024-08-07"

_spec = {
    "metadata": {
        # 产品名
        "serviceShortName": service_name,
        # 产品版本号
        "apiVersion": service_version,
        # 产品介绍
        "description": "this is a test module",
    },
    # 产品所有支持的接口
    "actions": {
        # 接口名推荐用小写，避免和云 API 的接口名冲突
        "add": {
            # 接口中文名
            "name": "测试接口",
            # 接口说明
            "document": "this is an test action",
            # 入参对象名，在 objects 中详细定义入参结构
            "input": "addRequest",
            # 出参对象名，在 objects 中详细定义出参结构
            "output": "addResponse",
            # 实际调用函数
            "action_caller": add_command,  # the function to call
        },
    },
    "objects": {
        "addRequest": {
            "members": [
                {
                    # 参数名
                    "name": "number1",
                    # int64, uint64, string, float, bool, date, datetime, datetime_iso, binary
                    "member": "int64",
                    # same as member
                    "type": "int64",
                    # 是否必传
                    "required": True,
                    # 参数说明
                    "document": "doc about number1",
                },
                {
                    "name": "number2",
                    "member": "int64",
                    "type": "int64",
                    "required": True,
                    "document": "doc about number2",
                },
            ],
        },
        "addResponse": {
            "members": [
                {
                    "name": "sum",
                    "member": "int64",
                    "type": "int64",
                    "required": True,
                    "document": "doc about arg1",
                },
            ],
        },
    },
    "version": "1.0",
}


def register_service(specs):
    specs[service_name] = {
        service_version: _spec,
    }



# coding: utf-8
import json
import logging

from tencentcloud.common import credential
from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.cvm.v20170312 import cvm_client, models


def add_command(args, parsed_globals):
    # get arguments from args
    number1 = args["number1"]
    number2 = args["number2"]
    print("%d + %d = %d\n" % (number1, number2, number1 + number2))

    # get secret key from parsed_globals
    secret_id = parsed_globals["secretId"]
    secret_key = parsed_globals["secretKey"]
    token = parsed_globals["token"]
    region = parsed_globals["region"] or "ap-guangzhou"

    # do api call with secret key
    cred = credential.Credential(secret_id, secret_key, token)
    cli = cvm_client.CvmClient(cred, region)

    req = models.DescribeInstancesRequest()
    try:
        resp = cli.DescribeInstances(req)
        print(resp.to_json_string(indent=2))
    except TencentCloudSDKException as e:
        logging.exception(e)



# encoding: utf-8
from tccli.plugins.sso import configs

_lang = configs.DEFAULT_LANG

texts = {
    "zh-CN": {
        "invalid_auth_url": "输入的 url 不合法: %s",
        "auth_url_not_configured": "尚未配置 sso url, 使用 `tccli sso configure %s--url https://your-login-domain.com` 来进行配置",
        "configure_succeed": "url 已配置为 '%s', 接下来可以使用 `tccli sso login` 进行登陆",
        "try_login_with_url": "在浏览器中转到以下链接, 并根据提示完成登录:",
        "account_select_prompt": "登录成功, 请选择您的用户: ",
        "role_select_prompt": "请选择您的角色: ",
        "login_success": "登录成功, 密钥凭证已被写入: %s",
        "logout_success": "登出成功, 密钥凭证已被删除: %s",
        "no_account": "未找到成员账号, 请确认是否同步过 CAM 角色",
        "no_role": "当前成员账号不存在授权角色",
    },
    "en-US": {
        "invalid_auth_url": "The entered url is invalid: %s",
        "auth_url_not_configured": "sso url is not configured yet, use `tccli sso configure %s--url https://your-login-domain.com` to configure",
        "configure_succeed": "The url has been configured as '%s', use `tccli sso login` to log in",
        "try_login_with_url": "Go to the following link in your browser, and complete the sign-in prompts:",
        "account_select_prompt": "Login succeed, choose your account: ",
        "role_select_prompt": "choose your role: ",
        "login_success": "Login succeed, credential has been written to %s",
        "logout_success": "Logout succeed, credential has been removed: %s",
        "no_account": "no account found, please confirm the account is synchronized",
        "no_role": "no role found in current account",
    }
}


def set_lang(lang):
    global _lang
    _lang = lang


def get(key):
    return texts[_lang][key]
